@@ -11,7 +11,9 @@
 
 Project home : https://github.com/WangLabCSU/bregr
 Documentation: https://wanglabcsu.github.io/bregr/
-Cite as      : arXiv:2110.14232
+Cite as      : https://doi.org/10.1002/mdr2.70028
+  Wang, S., Peng, Y., Shu, C., Wang, C., Yang, Y., Zhao, Y., Cui, Y., Hu, D. and Zhou, J.-G. (2025),
+  bregr: An R Package for Streamlined Batch Processing and Visualization of Biomedical Regression Models. Med Research.
 =======================================================================
                  ")
   packageStartupMessage(msg)
